package net.wanji.opt.entity.evaluation;

import com.fasterxml.jackson.annotation.JsonFormat;
import io.swagger.annotations.ApiModel;
import io.swagger.annotations.ApiModelProperty;
import lombok.Data;
import lombok.EqualsAndHashCode;
import lombok.experimental.Accessors;
import net.wanji.common.framework.domain.TrackableEntity;
import java.util.Date;
import java.math.BigDecimal;
import java.util.HashMap;
import java.util.Map;
import java.util.UUID;

/**
 * <p>
 * 交通事件信息
 * </p>
 *
 * @Author wangtao
 * @Date 2025-03-18
 */
@Data
@ApiModel(value="EventInfo对象", description="交通事件信息")
public class EventInfo extends TrackableEntity {
    private static final long serialVersionUID = 1L;

    @ApiModelProperty(value = "主键ID")
    private Long oid;

    @ApiModelProperty(value = "车牌号")
    private String plateNo;

    @ApiModelProperty(value = "参与者类别 1：机动车 2：非机动车 3：行人")
    private String objectType;

    @ApiModelProperty(value = "可信度")
    private Integer confidence;

    @ApiModelProperty(value = "检测时间")
    private Date detectTime;

    @ApiModelProperty(value = "事件等级：1扣分 2 罚款 3警告 0 未知")
    private Integer grade;

    @ApiModelProperty(value = "事件地点描述")
    private String placeDesc;

    @ApiModelProperty(value = "发生地点经度")
    private BigDecimal lng;

    @ApiModelProperty(value = "发生地点纬度")
    private BigDecimal lat;

    @ApiModelProperty(value = "事件一级类别 事件一级类别 1：机动车事件 2：非机动车事件 3：行人事件")
    private String category;

    @ApiModelProperty(value = "二级类别")
    private String type;

    @ApiModelProperty(value = "事件发生时间")
    @JsonFormat(pattern = "yyyy-MM-dd hh:mm:ss")
    private Date startTime;

    @ApiModelProperty(value = "事件结束时间")
    @JsonFormat(pattern = "yyyy-MM-dd hh:mm:ss")
    private Date endTime;

    @ApiModelProperty(value = "事件持续时长，单位秒")
    private Integer duration;

    @ApiModelProperty(value = "事件来源 1：系统检测 2：接处警 3：互联网 4：交管部门 5：大脑")
    private String source;

    @ApiModelProperty(value = "入库时间")
    private Date ruksj;

    @ApiModelProperty(value = "车道id")
    private String laneId;

    @ApiModelProperty(value = "路段id")
    private String rid;

    @ApiModelProperty(value = "渠化id")
    private String segmentId;

    @ApiModelProperty(value = "路口id")
    private String crossId;

    @ApiModelProperty(value = "路口所属绿波编号")
    private String greenId;

    @ApiModelProperty(value = "关联的事件摄像头信息ID")
    private Long cameraOid;

    @ApiModelProperty(value = "事件序列号作为主键")
    private String eventSerialNumber;

    private String dataStatus;

    @ApiModelProperty(value = "目标id")
    private String globalId;

    private Integer stationId;

    private String eventId;

    @ApiModelProperty(value = "备注")
    private String remark;

    private String extend;

    @ApiModelProperty(value = "分区字段")
    private Integer dt;

    @ApiModelProperty(value = "视频地址")
    private String videoUrls;

    @ApiModelProperty(value = "目标具体类型")
    private Integer targetType;

    @ApiModelProperty(value = "告警状态  0未处理 1分析中 2优化中 3优化完 4已结束")
    private Integer alarmStatus;

    @ApiModelProperty(value = "优化状态 0 未优化 1-优化过 根据上面告警状态如果有2 3状态认为优化过 ")
    private Integer optStatus;

    @ApiModelProperty(value = "修改时间")
    private Date modifyTime;

    @ApiModelProperty(value = "方向 1北...8西北")
    private String dir;

    @ApiModelProperty(value = "事件转向")
    private String turn;

    @ApiModelProperty(value = "失衡指数1-10")
    private Double unbalanceIndex;

    @ApiModelProperty(value = "溢出指数1-10 溢出程度的刻画（没溢出：1，即将溢出：3，溢出：5，溢停：7）")
    private Double spilloverIndex;

    @ApiModelProperty(value = "交通指数")
    private Double trafficIndex;

    /*****非数据库字段*******/
    private String typeName;

    //用于存放日期差-分钟
    private String diffTime;




}
